@@ -652,7 +652,10 @@ def biharmonic_friction(state):
 
     flux_east = allocate(state.dimensions, ("xu", "yt", "zt"))
     flux_north = allocate(state.dimensions, ("xt", "yu", "zt"))
-    fxa = npx.sqrt(abs(settings.A_hbi))
+    visc = npx.sqrt(abs(settings.A_hbi))
+
+    cost_scaled = vs.cost ** settings.biharmonic_friction_cosPower
+    cosu_scaled = vs.cosu ** settings.biharmonic_friction_cosPower
 
     """
     Zonal velocity
@@ -660,7 +663,8 @@ def biharmonic_friction(state):
     flux_east = update(
         flux_east,
         at[:-1, :, :],
-        fxa
+        visc
+        * cost_scaled[npx.newaxis, :, npx.newaxis]
         * (vs.u[1:, :, :, vs.tau] - vs.u[:-1, :, :, vs.tau])
         / (vs.cost[npx.newaxis, :, npx.newaxis] * vs.dxt[1:, npx.newaxis, npx.newaxis])
         * vs.maskU[1:, :, :]
@@ -669,32 +673,37 @@ def biharmonic_friction(state):
     flux_north = update(
         flux_north,
         at[:, :-1, :],
-        fxa
+        visc
+        * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
         * (vs.u[:, 1:, :, vs.tau] - vs.u[:, :-1, :, vs.tau])
         / vs.dyu[npx.newaxis, :-1, npx.newaxis]
         * vs.maskU[:, 1:, :]
         * vs.maskU[:, :-1, :]
         * vs.cosu[npx.newaxis, :-1, npx.newaxis],
     )
+
     if settings.enable_noslip_lateral:
         flux_north = update_add(
             flux_north,
             at[:, :-1],
             2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
             * vs.u[:, 1:, :, vs.tau]
             / vs.dyu[npx.newaxis, :-1, npx.newaxis]
             * vs.maskU[:, 1:]
             * (1 - vs.maskU[:, :-1])
             * vs.cosu[npx.newaxis, :-1, npx.newaxis]
             - 2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
             * vs.u[:, :-1, :, vs.tau]
             / vs.dyu[npx.newaxis, :-1, npx.newaxis]
             * (1 - vs.maskU[:, 1:])
             * vs.maskU[:, :-1]
             * vs.cosu[npx.newaxis, :-1, npx.newaxis],
         )
+
     flux_east = update(flux_east, at[-1, :, :], 0.0)
     flux_north = update(flux_north, at[:, -1, :], 0.0)
 
@@ -711,7 +720,8 @@ def biharmonic_friction(state):
     flux_east = update(
         flux_east,
         at[:-1, :, :],
-        fxa
+        visc
+        * cost_scaled[npx.newaxis, :, npx.newaxis]
         * (del2[1:, :, :] - del2[:-1, :, :])
         / (vs.cost[npx.newaxis, :, npx.newaxis] * vs.dxt[1:, npx.newaxis, npx.newaxis])
         * vs.maskU[1:, :, :]
@@ -720,32 +730,37 @@ def biharmonic_friction(state):
     flux_north = update(
         flux_north,
         at[:, :-1, :],
-        fxa
+        visc
+        * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
         * (del2[:, 1:, :] - del2[:, :-1, :])
         / vs.dyu[npx.newaxis, :-1, npx.newaxis]
         * vs.maskU[:, 1:, :]
         * vs.maskU[:, :-1, :]
         * vs.cosu[npx.newaxis, :-1, npx.newaxis],
     )
+
     if settings.enable_noslip_lateral:
         flux_north = update_add(
             flux_north,
             at[:, :-1, :],
             2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
             * del2[:, 1:, :]
             / vs.dyu[npx.newaxis, :-1, npx.newaxis]
             * vs.maskU[:, 1:, :]
             * (1 - vs.maskU[:, :-1, :])
             * vs.cosu[npx.newaxis, :-1, npx.newaxis]
             - 2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :-1, npx.newaxis]
             * del2[:, :-1, :]
             / vs.dyu[npx.newaxis, :-1, npx.newaxis]
             * (1 - vs.maskU[:, 1:, :])
             * vs.maskU[:, :-1, :]
             * vs.cosu[npx.newaxis, :-1, npx.newaxis],
         )
+
     flux_east = update(flux_east, at[-1, :, :], 0.0)
     flux_north = update(flux_north, at[:, -1, :], 0.0)
 
@@ -764,6 +779,7 @@ def biharmonic_friction(state):
             / (vs.cost[npx.newaxis, 2:-2, npx.newaxis] * vs.dyt[npx.newaxis, 2:-2, npx.newaxis])
         ),
     )
+
     if settings.enable_conserve_energy:
         """
         diagnose dissipation by lateral friction
@@ -795,33 +811,39 @@ def biharmonic_friction(state):
     flux_east = update(
         flux_east,
         at[:-1, :, :],
-        fxa
+        visc
+        * cosu_scaled[npx.newaxis, :, npx.newaxis]
         * (vs.v[1:, :, :, vs.tau] - vs.v[:-1, :, :, vs.tau])
         / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
         * vs.maskV[1:, :, :]
         * vs.maskV[:-1, :, :],
     )
+
     if settings.enable_noslip_lateral:
         flux_east = update_add(
             flux_east,
             at[:-1, :, :],
             2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :, npx.newaxis]
             * vs.v[1:, :, :, vs.tau]
             / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
             * vs.maskV[1:, :, :]
             * (1 - vs.maskV[:-1, :, :])
             - 2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :, npx.newaxis]
             * vs.v[:-1, :, :, vs.tau]
             / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
             * (1 - vs.maskV[1:, :, :])
             * vs.maskV[:-1, :, :],
         )
+
     flux_north = update(
         flux_north,
         at[:, :-1, :],
-        fxa
+        visc
+        * cost_scaled[npx.newaxis, :-1, npx.newaxis]
         * (vs.v[:, 1:, :, vs.tau] - vs.v[:, :-1, :, vs.tau])
         / vs.dyt[npx.newaxis, 1:, npx.newaxis]
         * vs.cost[npx.newaxis, 1:, npx.newaxis]
@@ -843,33 +865,39 @@ def biharmonic_friction(state):
     flux_east = update(
         flux_east,
         at[:-1, :, :],
-        fxa
+        visc
+        * cosu_scaled[npx.newaxis, :, npx.newaxis]
         * (del2[1:, :, :] - del2[:-1, :, :])
         / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
         * vs.maskV[1:, :, :]
         * vs.maskV[:-1, :, :],
     )
+
     if settings.enable_noslip_lateral:
         flux_east = update_add(
             flux_east,
             at[:-1, :, :],
             2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :, npx.newaxis]
             * del2[1:, :, :]
             / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
             * vs.maskV[1:, :, :]
             * (1 - vs.maskV[:-1, :, :])
             - 2
-            * fxa
+            * visc
+            * cosu_scaled[npx.newaxis, :, npx.newaxis]
             * del2[:-1, :, :]
             / (vs.cosu[npx.newaxis, :, npx.newaxis] * vs.dxu[:-1, npx.newaxis, npx.newaxis])
             * (1 - vs.maskV[1:, :, :])
             * vs.maskV[:-1, :, :],
         )
+
     flux_north = update(
         flux_north,
         at[:, :-1, :],
-        fxa
+        visc
+        * cost_scaled[npx.newaxis, :-1, npx.newaxis]
         * (del2[:, 1:, :] - del2[:, :-1, :])
         / vs.dyt[npx.newaxis, 1:, npx.newaxis]
         * vs.cost[npx.newaxis, 1:, npx.newaxis]
